#! /usr/bin/perl -w
# $Id$
# $URL$

use strict;
use File::Basename;
use Getopt::Long;
use LWP::Simple;

use lib "/usr/lib/nagios/plugins";
use utils qw (%ERRORS &print_revision);

sub print_help();
sub print_usage();

my $ME = basename $0;
my $VERSION = '1.2';

my ( $opt_u, $opt_s, $opt_V, $opt_h, $opt_b );
my ( $result, $found, $message, $version, $current_version );

$opt_u = 'http://www.avira.com/de/support-download-avira-antivir-webgate';
$opt_s = '<h2>Avira AntiVir WebGate</h2>.*(?:\n.*){27}<span class="version">Version:\s*(\d+\.\d+\.\d+\.\d+)(-\d+)?\s*</span>';
$opt_b = "/usr/lib/AntiVir/webgate/avwebgate.bin";

Getopt::Long::Configure('bundling');
GetOptions(
    "V"              => \$opt_V,
    "version"        => \$opt_V,
    "h"              => \$opt_h,
    "help"           => \$opt_h,
    "b=s"            => \$opt_b,
    "binary"         => \$opt_b,
    "u=s"            => \$opt_u,
    "url=s"          => \$opt_u,
    "s=s"            => \$opt_s,
    "search=s"       => \$opt_s
);

if ($opt_V) {
    print_revision( $ME, $VERSION );
    exit $ERRORS{"OK"};
}

if ($opt_h) {
    print_help();
    exit $ERRORS{"OK"};
}

# check avwebgate binary
unless ( -x $opt_b ) {
    print "AVWEBGATE CRITICAL: AntiVir WebGate not found or not executable - $opt_b\n";
    exit $ERRORS{"CRITICAL"};
}

{ 
	get($opt_u) =~ /$opt_s/;
	unless ($version = $1) {
		print "AVWEBGATE CRITICAL: cannot get version info from avira server\n";
		exit $ERRORS{"CRITICAL"};
	}
}

{
	qx(LANG= $opt_b --version) =~ /product version:\s*(\S+)/;
	unless ($current_version = $1) {
		print "AVWEBGATE CRITICAL: cannot get local version info\n";
		exit $ERRORS{"CRITICAL"};
	}
}

$result = ($current_version eq $version) ? "OK" : "WARNING";

if ($result eq "WARNING") {
	$message = "new version available: $version";
	print "AVWEBGATE $result: $message\n";
	exit $ERRORS{$result};
} else {
	$message = "current version: $current_version";
	print "AVWEBGATE $result: $message\n";
	exit $ERRORS{$result};
}

sub print_usage() {
    print "Usage:\n";
    print "  $ME [-b <binary>] [-u <url>] [-s <search>\n";
    print "  $ME [-h | --help]\n";
    print "  $ME [-V | --version]\n";
}

sub print_help() {
    print_revision( $ME, $VERSION );
    print "Copyright (c) 2008 Christian Arnold\n\n";
    print "This plugin checks for new versions of Avira AntiVir WebGate.\n\n";
    print_usage();
    print "\n";
    print "  -b, --binary <binary>\n";
    print "     Path of AntiVir WebGate binary (default: $opt_b)\n";
    print "  -u, --url <url>\n";
    print "     URL where will be look for the search string (default: $opt_u)\n";
    print "  -s, --search <search>\n";
    print "     Search string on the url - put the pattern matching the version in parenthesis like 'optionalprefix(theversion)optionalpostfix' (default: $opt_s)\n";
    print "\n";
}
